# Epico

Just some epic python utilities


##  Functions
 -  epico.pause()
 -  epico.dir.delete(path, recursive=False)
 -  epico.dir.create(path)
 -  epico.file.create(filename, encoding=None)
 -  epico.file.append(filename, data, encoding=None)
 -  epico.file.write(filename, data, encoding=None)
 -  epico.file.delete(filename)
 -  epico.file.exists(filename)
 -  epico.file.read(filename, mode='s')
